@@ -1,8 +1,8 @@
 """
 PyTorch Forecasting package for timeseries forecasting with PyTorch.
 """
-from pytorch_forecasting.models import TemporalFusionTransformer, NBeats, Baseline
-from pytorch_forecasting.data import TimeSeriesDataSet, GroupNormalizer, EncoderNormalizer
+from pytorch_forecasting.data import EncoderNormalizer, GroupNormalizer, TimeSeriesDataSet
+from pytorch_forecasting.models import Baseline, NBeats, TemporalFusionTransformer
 
 __all__ = [
     "TimeSeriesDataSet",
@@ -13,4 +13,4 @@ __all__ = [
     "Baseline",
 ]
 
-__version__ = "0.3.0"
+__version__ = "0.3.1"
