@@ -4,7 +4,7 @@ Datasets, etc. for timeseries data.
 Handling timeseries data is not trivial. It requires special treatment. This sub-package provides the necessary tools
 to abstracts the necessary work.
 """
+from pytorch_forecasting.data.encoders import EncoderNormalizer, GroupNormalizer, NaNLabelEncoder, TorchNormalizer
 from pytorch_forecasting.data.timeseries import TimeSeriesDataSet
-from pytorch_forecasting.data.encoders import NaNLabelEncoder, GroupNormalizer, TorchNormalizer, EncoderNormalizer
 
 __all__ = ["TimeSeriesDataSet", "NaNLabelEncoder", "GroupNormalizer", "TorchNormalizer", "EncoderNormalizer"]
