@@ -4,29 +4,40 @@ Timeseries datasets.
 Timeseries data is special and has to be processed and fed to algorithms in a special way. This module
 defines a class that is able to handle a wide variety of timeseries data problems.
 """
-import warnings
 from copy import deepcopy
 import inspect
-from typing import Union, Dict, List, Tuple, Any
+from typing import Any, Dict, List, Tuple, Union
+import warnings
 
 import matplotlib.pyplot as plt
-import pandas as pd
 import numpy as np
-
+import pandas as pd
+from sklearn.exceptions import NotFittedError
+from sklearn.preprocessing import StandardScaler
+from sklearn.utils.validation import check_is_fitted
 import torch
 from torch.distributions import Beta
 from torch.nn.utils import rnn
-from torch.utils.data import Dataset, DataLoader
+from torch.utils.data import DataLoader, Dataset
 
-from sklearn.utils.validation import check_is_fitted
-from sklearn.exceptions import NotFittedError
-from sklearn.preprocessing import StandardScaler
-
-from pytorch_forecasting.data.encoders import NaNLabelEncoder, GroupNormalizer, EncoderNormalizer, TorchNormalizer
+from pytorch_forecasting.data.encoders import EncoderNormalizer, GroupNormalizer, NaNLabelEncoder, TorchNormalizer
 
 
 class TimeSeriesDataSet(Dataset):
-    """PyTorch Dataset for fitting timeseries models"""
+    """
+    PyTorch Dataset for fitting timeseries models.
+
+    The dataset automates common tasks such as
+
+    * scaling and encoding of variables
+    * normalizing the target variable
+    * efficiently converting timeseries in pandas dataframes to torch tensors
+    * holding information about static and time-varying variables known and unknown in the future
+    * holiding information about related categories (such as holidays)
+    * downsampling for data augmentation
+    * generating inference, validation and test datasets
+    * etc.
+    """
 
     def __init__(
         self,
@@ -874,14 +885,12 @@ class TimeSeriesDataSet(Dataset):
 
             if self._overwrite_values["variable"] in self.reals:
                 idx = self.reals.index(self._overwrite_values["variable"])
-                data_cont = data_cont  # not to overwrite original data
                 data_cont[positions, idx] = self._overwrite_values["values"]
             else:
                 assert (
                     self._overwrite_values["variable"] in self.flat_categoricals
                 ), "overwrite values variable has to be either in real or categorical variables"
                 idx = self.flat_categoricals.index(self._overwrite_values["variable"])
-                data_cat = data_cat  # not to overwrite original data
                 data_cat[positions, idx] = self._overwrite_values["values"]
 
         return (
