@@ -1,16 +1,15 @@
 """
 Implementation of metrics for (mulit-horizon) timeseries forecasting.
 """
+import abc
 from typing import Dict, List, Union
 
+from pytorch_lightning.metrics import TensorMetric
+import scipy.stats
 import torch
 from torch import nn
 import torch.nn.functional as F
 from torch.nn.utils import rnn
-import abc
-from pytorch_lightning.metrics import TensorMetric
-
-import scipy.stats
 
 
 class Metric(TensorMetric):
@@ -181,7 +180,8 @@ class PoissonLoss(MultiHorizonMetric):
     def to_quantiles(self, out: Dict[str, torch.Tensor], quantiles=None):
         if quantiles is None:
             quantiles = self.quantiles
-        return scipy.stats.poisson(super().to_prediction(out)).ppf(quantiles)
+        predictions = super().to_prediction(out)
+        return torch.stack([torch.tensor(scipy.stats.poisson(predictions).ppf(q)) for q in quantiles], dim=-1)
 
 
 class QuantileLoss(MultiHorizonMetric):
