@@ -2,15 +2,15 @@
 N-Beats model for timeseries forecasting without covariates.
 """
 from typing import Dict, List
-import matplotlib.pyplot as plt
 
+import matplotlib.pyplot as plt
 import torch
 from torch import nn
 
 from pytorch_forecasting.data import TimeSeriesDataSet
 from pytorch_forecasting.metrics import SMAPE
 from pytorch_forecasting.models.base_model import BaseModel
-from pytorch_forecasting.models.nbeats.sub_modules import NBEATSTrendBlock, NBEATSGenericBlock, NBEATSSeasonalBlock
+from pytorch_forecasting.models.nbeats.sub_modules import NBEATSGenericBlock, NBEATSSeasonalBlock, NBEATSTrendBlock
 
 
 class NBeats(BaseModel):
@@ -37,6 +37,10 @@ class NBeats(BaseModel):
         """
         Initialize NBeats Model - use its :py:meth:`~from_dataset` method if possible.
 
+        Based on the article
+        `N-BEATS: Neural basis expansion analysis for interpretable time series
+        forecasting <http://arxiv.org/abs/1905.10437>`_.
+
         Args:
             stack_types: One of the following values: “generic”, “seasonality" or “trend". A list of strings
                 of length 1 or ‘num_stacks’. Default and recommended value
